summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Ivan Vangelista <mesgnet@yahoo.it>2018-08-24 22:59:41 +0200
committer Ivan Vangelista <mesgnet@yahoo.it>2018-08-24 22:59:41 +0200
commitdabf58e85af92a40c410fe502170a042b7e41f95 (patch)
treea762a8a8e5f859f1f9653b98378cd888b47bad12
parent07db2bb5345f566d01ba819b2294fac2646eb335 (diff)
new working clone
----------------------------- Raiden II (Korea) [Jorge Silva]
-rw-r--r--src/mame/drivers/raiden2.cpp44
-rw-r--r--src/mame/mame.lst1
2 files changed, 43 insertions, 2 deletions
diff --git a/src/mame/mame.lst b/src/mame/mame.lst
index 418c8c0d8f9..d275da90db3 100644
--- a/src/mame/mame.lst
+++ b/src/mame/mame.lst
@@ -32832,6 +32832,7 @@ raiden2g // (c) 1993 Seibu Kaihatsu + Tuning license
raiden2hk // (c) 1993 Seibu Kaihatsu + Metrotainment license
raiden2i // (c) 1993 Seibu Kaihatsu
raiden2j // (c) 1993 Seibu Kaihatsu
+raiden2k // (c) 1993 Seibu Kaihatsu
raiden2nl // (c) 1993 Seibu Kaihatsu
raiden2sw // (c) 1993 Seibu Kaihats
raiden2u // (c) 1993 Seibu Kaihatsu + Fabtek license
diff --git a/src/mame/drivers/raiden2.cpp b/src/mame/drivers/raiden2.cpp
index f17c8de47c1..724a9ec1fe7 100644
--- a/src/mame/drivers/raiden2.cpp
+++ b/src/mame/drivers/raiden2.cpp
@@ -9,7 +9,7 @@
* xsedae - it does an "8-liner"-style scroll during attract, doesn't work too well.
* sprite chip is the same as seibuspi.c and feversoc.c, needs device-ification and merging.
* sprite chip also uses first entry for "something" that isn't sprite, some of them looks clipping
regions (150 - ff in zeroteam, 150 - 0 and 150 - 80 in raiden2). Latter probably do double buffering
@@ -164,7 +164,7 @@ Protection Notes:
to be the actual MCU which is probably internal to one of the Seibu
customs.
- The games in legionna.c use (almost?) the same protection chips.
+ The games in legionna.cpp use (almost?) the same protection chips.
********************************************************************************************************/
@@ -2073,6 +2073,45 @@ ROM_START( raiden2i )
ROM_END
+ROM_START( raiden2k )
+ ROM_REGION( 0x200000, "maincpu", 0 ) /* v30 main cpu */
+ ROM_LOAD16_BYTE("k1.u0211", 0x000000, 0x80000, CRC(1fcc08cf) SHA1(bff7076ced189120166217d71e2762bb98aad7c8) ) // hand-written
+ ROM_RELOAD(0x100000, 0x80000)
+ ROM_LOAD16_BYTE("k2.u0212", 0x000001, 0x80000, CRC(59a744ca) SHA1(5fdd7dd4049f944df23371e2e2d3133b10c66ab8) ) // hand-written
+ ROM_RELOAD(0x100001, 0x80000)
+
+ ROM_REGION( 0x40000, "user2", 0 ) /* COPX */
+ ROM_LOAD( "copx-d2.u0313", 0x00000, 0x40000, CRC(a6732ff9) SHA1(c4856ec77869d9098da24b1bb3d7d58bb74b4cda) ) /* Soldered MASK ROM */
+
+ ROM_REGION( 0x20000, "audiocpu", ROMREGION_ERASEFF ) /* 64k code for sound Z80 */
+ ROM_LOAD( "snd.u1110", 0x000000, 0x08000, CRC(f51a28f9) SHA1(7ae2e2ba0c8159a544a8fd2bb0c2c694ba849302) )
+ ROM_CONTINUE(0x10000,0x8000)
+ ROM_COPY( "audiocpu", 0x000000, 0x018000, 0x08000 )
+
+ ROM_REGION( 0x020000, "gfx1", 0 ) /* chars */
+ ROM_LOAD( "seibu7.u0724", 0x000000, 0x020000, CRC(c9ec9469) SHA1(a29f480a1bee073be7a177096ef58e1887a5af24) ) /* PCB silkscreened FX0 */
+
+ ROM_REGION( 0x400000, "gfx2", 0 ) /* background gfx */
+ ROM_LOAD( "raiden_2_seibu_bg-1.u0714", 0x000000, 0x200000, CRC(e61ad38e) SHA1(63b06cd38db946ad3fc5c1482dc863ef80b58fec) ) /* Soldered MASK ROM */
+ ROM_LOAD( "raiden_2_seibu_bg-2.u075", 0x200000, 0x200000, CRC(a694a4bb) SHA1(39c2614d0effc899fe58f735604283097769df77) ) /* Soldered MASK ROM */
+
+ ROM_REGION32_LE( 0x800000, "gfx3", 0 ) /* sprite gfx (encrypted) */
+ ROM_LOAD32_WORD( "raiden_2_seibu_obj-1.u0811", 0x000000, 0x200000, CRC(ff08ef0b) SHA1(a1858430e8171ca8bab785457ef60e151b5e5cf1) ) /* Soldered MASK ROM */
+ ROM_LOAD32_WORD( "raiden_2_seibu_obj-2.u082", 0x000002, 0x200000, CRC(638eb771) SHA1(9774cc070e71668d7d1d20795502dccd21ca557b) ) /* Soldered MASK ROM */
+ ROM_LOAD32_WORD( "raiden_2_seibu_obj-3.u0837", 0x400000, 0x200000, CRC(897a0322) SHA1(abb2737a2446da5b364fc2d96524b43d808f4126) ) /* Soldered MASK ROM */
+ ROM_LOAD32_WORD( "raiden_2_seibu_obj-4.u0836", 0x400002, 0x200000, CRC(b676e188) SHA1(19cc838f1ccf9c4203cd0e5365e5d99ff3a4ff0f) ) /* Soldered MASK ROM */
+
+ ROM_REGION( 0x100000, "oki1", 0 ) /* ADPCM samples */
+ ROM_LOAD( "seibu6.u1017", 0x00000, 0x40000, CRC(fb0fca23) SHA1(4b2217b121a66c5ab6015537609cf908ffedaf86) ) /* PCB silkscreened VOICE1 */
+
+ ROM_REGION( 0x100000, "oki2", 0 ) /* ADPCM samples */
+ ROM_LOAD( "raiden_2_pcm.u1018", 0x00000, 0x40000, CRC(8cf0d17e) SHA1(0fbe0b1e1ca5360c7c8329331408e3d799b4714c) ) /* Soldered MASK ROM */
+
+ ROM_REGION( 0x10000, "pals", 0 ) /* PALS */
+ ROM_LOAD( "jj4b02__ami18cv8-15.u0342.jed", 0x0000, 0x288, NO_DUMP)
+ ROM_LOAD( "jj4b01__mmipal16l8bcn.u0341.jed", 0x0000, 0x335, CRC(d1a039af) SHA1(f88ff8674d5be17ae9085b51aefcf6abf0574883) )
+ROM_END
+
/*
Raiden 2, Seibu License, Easy Version
@@ -3286,6 +3325,7 @@ GAME( 1993, raiden2sw, raiden2, raiden2, raiden2, raiden2_state, init_raiden
GAME( 1993, raiden2f, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (France)", MACHINE_SUPPORTS_SAVE ) // raiden2f & raiden2nl share same code base
GAME( 1993, raiden2nl, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (Holland)", MACHINE_SUPPORTS_SAVE ) // raiden2f & raiden2nl share same code base
GAME( 1993, raiden2i, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (Italy)", MACHINE_SUPPORTS_SAVE ) // rev 2
+GAME( 1993, raiden2k, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (Korea)", MACHINE_SUPPORTS_SAVE )
GAME( 1993, raiden2e, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (easy version, Korea?)", MACHINE_SUPPORTS_SAVE ) // rev 3 (Region 0x04) - Korea?, if regions are the same as RDX, no license or region message tho
GAME( 1993, raiden2ea, raiden2, raiden2, raiden2, raiden2_state, init_raiden2, ROT270, "Seibu Kaihatsu", "Raiden II (easy version, Japan?)", MACHINE_SUPPORTS_SAVE ) // rev 4 (Region 0x00) - Should be Japan, but the easy sets have no 'FOR USE IN JAPAN ONLY' display even when region is 00
@@ -9,7 +9,7 @@
* xsedae - it does an "8-liner"-style scroll during attract, doesn't work too well.
- * sprite chip is the same as seibuspi.c and feversoc.c, needs device-ification and merging.
+ * sprite chip is the same as seibuspi.cpp and feversoc.cpp, needs device-ification and merging.
* sprite chip also uses first entry for "something" that isn't sprite, some of them looks clipping
regions (150 - ff in zeroteam, 150 - 0 and 150 - 80 in raiden2). Latter probably do double buffering